@@ -2,6 +2,10 @@
 
 config.addonManager.enable        =
 "是否启用扩展的附加插件管理器(Addon Manager)"
+config.addonManager.repositoryBranch =
+"指定插件管理器(Addon Manager)使用的git仓库分支"
+config.addonManager.repositoryPath =
+"指定插件管理器(Addon Manager)使用的git仓库路径"
 config.runtime.version            =
 "Lua运行版本。"
 config.runtime.path               =
@@ -251,6 +255,8 @@ config.hint.arrayIndex.Disable           =
 '禁用数组索引提示。'
 config.hint.await                        =
 '如果调用的函数被标记为了 `---@async` ，则在调用处提示 `await` 。'
+config.hint.awaitPropagate               =
+'启用 `await` 的传播, 当一个函数调用了一个`---@async`标记的函数时，会自动标记为`---@async`。'
 config.hint.semicolon                    =
 '若语句尾部没有分号，则显示虚拟分号。'
 config.hint.semicolon.All                =
