@@ -1,5 +1,4 @@
 local fs           = require 'bee.filesystem'
-local platform     = require 'bee.platform'
 
 local type         = type
 local ioOpen       = io.open
@@ -7,16 +6,16 @@ local pcall        = pcall
 local pairs        = pairs
 local setmetatable = setmetatable
 local next         = next
-local ipairs       = ipairs
 local tostring     = tostring
 local tableSort    = table.sort
 
 _ENV = nil
 
+---@class fs-utility
 local m = {}
 --- 读取文件
----@param path string
-function m.loadFile(path)
+---@param path string|fs.path
+function m.loadFile(path, keepBom)
     if type(path) ~= 'string' then
         ---@diagnostic disable-next-line: undefined-field
         path = path:string()
@@ -25,16 +24,22 @@ function m.loadFile(path)
     if not f then
         return nil, e
     end
-    if f:read(3) ~= '\xEF\xBB\xBF' then
-        f:seek("set")
-    end
-    local buf = f:read 'a'
+    local text = f:read 'a'
     f:close()
-    return buf
+    if not keepBom then
+        if text:sub(1, 3) == '\xEF\xBB\xBF' then
+            return text:sub(4)
+        end
+        if text:sub(1, 2) == '\xFF\xFE'
+        or text:sub(1, 2) == '\xFE\xFF' then
+            return text:sub(3)
+        end
+    end
+    return text
 end
 
 --- 写入文件
----@param path string
+---@param path any
 ---@param content string
 function m.saveFile(path, content)
     if type(path) ~= 'string' then
@@ -89,11 +94,15 @@ local function split(str, sep)
     return t
 end
 
+---@class dummyfs
+---@operator div(string|fs.path|dummyfs): dummyfs
+---@field files table
 local dfs = {}
 dfs.__index = dfs
 dfs.type = 'dummy'
 dfs.path = ''
 
+---@return dummyfs
 function m.dummyFS(t)
     return setmetatable({
         files = t or {},
@@ -117,6 +126,7 @@ function dfs:__div(filename)
     return new
 end
 
+---@package
 function dfs:_open(index)
     local paths = split(self.path, '[/\\]')
     local current = self.files
@@ -136,6 +146,7 @@ function dfs:_open(index)
     return current
 end
 
+---@package
 function dfs:_filename()
     return self.path:match '[^/\\]+$'
 end
@@ -160,6 +171,7 @@ function dfs:string()
     return self.path
 end
 
+---@return fun(): dummyfs?
 function dfs:listDirectory()
     local dir = self:_open()
     if type(dir) ~= 'table' then
@@ -204,6 +216,9 @@ function dfs:exists()
 end
 
 function dfs:createDirectories(path)
+    if not path then
+        return false
+    end
     if type(path) ~= 'string' then
         path = path:string()
     end
@@ -224,6 +239,9 @@ function dfs:createDirectories(path)
 end
 
 function dfs:saveFile(path, text)
+    if not path then
+        return false, 'no path'
+    end
     if type(path) ~= 'string' then
         path = path:string()
     end
@@ -241,8 +259,12 @@ function dfs:saveFile(path, text)
         return false, '无法打开:' .. path
     end
     dir[filename] = text
+    return true
 end
 
+---@param path   string|fs.path|dummyfs
+---@param option table
+---@return fs.path|dummyfs?
 local function fsAbsolute(path, option)
     if type(path) == 'string' then
         local suc, res = pcall(fs.path, path)
@@ -262,19 +284,25 @@ local function fsAbsolute(path, option)
     return res
 end
 
-local function fsIsDirectory(path, option)
+local function fsIsDirectory(path)
+    if not path then
+        return false
+    end
     if path.type == 'dummy' then
         return path:isDirectory()
     end
-    local suc, res = pcall(fs.is_directory, path)
-    if not suc then
-        option.err[#option.err+1] = res
-        return false
-    end
-    return res
+    ---@cast path -dummyfs
+    local status = fs.symlink_status(path):type()
+    return status == 'directory'
 end
 
+---@param path fs.path|dummyfs|nil
+---@param option table
+---@return fun(): fs.path|dummyfs|nil
 local function fsPairs(path, option)
+    if not path then
+        return function () end
+    end
     if path.type == 'dummy' then
         return path:listDirectory()
     end
@@ -287,6 +315,9 @@ local function fsPairs(path, option)
 end
 
 local function fsRemove(path, option)
+    if not path then
+        return false
+    end
     if path.type == 'dummy' then
         return path:remove()
     end
@@ -298,6 +329,9 @@ local function fsRemove(path, option)
 end
 
 local function fsExists(path, option)
+    if not path then
+        return false
+    end
     if path.type == 'dummy' then
         return path:exists()
     end
@@ -310,7 +344,11 @@ local function fsExists(path, option)
 end
 
 local function fsSave(path, text, option)
+    if not path then
+        return false
+    end
     if path.type == 'dummy' then
+        ---@cast path -fs.path
         local dir = path:_open(-2)
         if not dir then
             option.err[#option.err+1] = '无法打开:' .. path:string()
@@ -337,6 +375,9 @@ local function fsSave(path, text, option)
 end
 
 local function fsLoad(path, option)
+    if not path then
+        return nil
+    end
     if path.type == 'dummy' then
         local text = path:_open()
         if type(text) == 'string' then
@@ -346,6 +387,7 @@ local function fsLoad(path, option)
             return nil
         end
     else
+        ---@cast path -dummyfs
         local text, err = m.loadFile(path)
         if text then
             return text
@@ -357,6 +399,9 @@ local function fsLoad(path, option)
 end
 
 local function fsCopy(source, target, option)
+    if not source or not target then
+        return
+    end
     if source.type == 'dummy' then
         local sourceText = source:_open()
         if not sourceText then
@@ -365,6 +410,7 @@ local function fsCopy(source, target, option)
         end
         return fsSave(target, sourceText, option)
     else
+        ---@cast source -dummyfs
         if target.type == 'dummy' then
             local sourceText, err = m.loadFile(source)
             if not sourceText then
@@ -383,7 +429,12 @@ local function fsCopy(source, target, option)
     return true
 end
 
+---@param path dummyfs|fs.path
+---@param option table
 local function fsCreateDirectories(path, option)
+    if not path then
+        return
+    end
     if path.type == 'dummy' then
         return path:createDirectories()
     end
@@ -396,11 +447,14 @@ local function fsCreateDirectories(path, option)
 end
 
 local function fileRemove(path, option)
+    if not path then
+        return
+    end
     if option.onRemove and option.onRemove(path) == false then
         return
     end
-    if fsIsDirectory(path, option) then
-        for child in fsPairs(path) do
+    if fsIsDirectory(path) then
+        for child in fsPairs(path, option) do
             fileRemove(child, option)
         end
     end
@@ -409,13 +463,19 @@ local function fileRemove(path, option)
     end
 end
 
+---@param source fs.path|dummyfs?
+---@param target fs.path|dummyfs?
+---@param option table
 local function fileCopy(source, target, option)
-    local isDir1   = fsIsDirectory(source, option)
-    local isDir2   = fsIsDirectory(target, option)
+    if not source or not target then
+        return
+    end
+    local isDir1   = fsIsDirectory(source)
+    local isDir2   = fsIsDirectory(target)
     local isExists = fsExists(target, option)
     if isDir1 then
         if isDir2 or fsCreateDirectories(target, option) then
-            for filePath in fsPairs(source) do
+            for filePath in fsPairs(source, option) do
                 local name = filePath:filename():string()
                 fileCopy(filePath, target / name, option)
             end
@@ -439,17 +499,31 @@ local function fileCopy(source, target, option)
     end
 end
 
+---@param source fs.path|dummyfs?
+---@param target fs.path|dummyfs?
+---@param option table
 local function fileSync(source, target, option)
-    local isDir1   = fsIsDirectory(source, option)
-    local isDir2   = fsIsDirectory(target, option)
+    if not source or not target then
+        return
+    end
+    local isDir1   = fsIsDirectory(source)
+    local isDir2   = fsIsDirectory(target)
     local isExists = fsExists(target, option)
     if isDir1 then
         if isDir2 then
             local fileList = m.fileList()
-            for filePath in fs.pairs(target) do
-                fileList[filePath] = true
+            if type(target) == 'table' then
+                ---@cast target dummyfs
+                for filePath in target:listDirectory() do
+                    fileList[filePath] = true
+                end
+            else
+                ---@cast target fs.path
+                for filePath in fs.pairs(target) do
+                    fileList[filePath] = true
+                end
             end
-            for filePath in fsPairs(source) do
+            for filePath in fsPairs(source, option) do
                 local name = filePath:filename():string()
                 local targetPath = target / name
                 fileSync(filePath, targetPath, option)
@@ -462,8 +536,8 @@ local function fileSync(source, target, option)
             if isExists then
                 fileRemove(target, option)
             end
-            if fsCreateDirectories(target) then
-                for filePath in fsPairs(source) do
+            if fsCreateDirectories(target, option) then
+                for filePath in fsPairs(source, option) do
                     local name = filePath:filename():string()
                     fileCopy(filePath, target / name, option)
                 end
@@ -494,7 +568,6 @@ end
 --- 文件列表
 function m.fileList(option)
     option = option or buildOption(option)
-    local os = platform.OS
     local keyMap = {}
     local fileList = {}
     local function computeKey(path)
@@ -542,38 +615,41 @@ function m.fileRemove(path, option)
 end
 
 --- 复制文件（夹）
----@param source string
----@param target string
+---@param source string|fs.path|dummyfs
+---@param target string|fs.path|dummyfs
 ---@return table
 function m.fileCopy(source, target, option)
     option = buildOption(option)
-    source = fsAbsolute(source, option)
-    target = fsAbsolute(target, option)
+    local fsSource = fsAbsolute(source, option)
+    local fsTarget = fsAbsolute(target, option)
 
-    fileCopy(source, target, option)
+    fileCopy(fsSource, fsTarget, option)
 
     return option
 end
 
 --- 同步文件（夹）
----@param source string
----@param target string
+---@param source string|fs.path|dummyfs
+---@param target string|fs.path|dummyfs
 ---@return table
 function m.fileSync(source, target, option)
     option = buildOption(option)
-    source = fsAbsolute(source, option)
-    target = fsAbsolute(target, option)
+    local fsSource = fsAbsolute(source, option)
+    local fsTarget = fsAbsolute(target, option)
 
-    fileSync(source, target, option)
+    fileSync(fsSource, fsTarget, option)
 
     return option
 end
 
+---@param dir fs.path
+---@param callback fun(fullPath: fs.path)
 function m.scanDirectory(dir, callback)
     for fullpath in fs.pairs(dir) do
-        if fs.is_directory(fullpath) then
+        local status = fs.symlink_status(fullpath):type()
+        if status == 'directory' then
             m.scanDirectory(fullpath, callback)
-        else
+        elseif status == 'regular' then
             callback(fullpath)
         end
     end
